pro SA_incident_intensities,model_name,alt,az,tip_away_from_sun, $
  orthogonal_tip,intens

; Compute the intensities incident on each Solar Aureole pixel
; in the grid of pixels for the Vertical and Horizontal at each wavelength
; of a model files (INTENSI.OUT)
; Inputs:
;   model_name = a file name containing the path to the INTENSI.OUT file of the model
;   alt = the altitude of the data set in km
;   tip_away_from_sun = the component of the tip of the Huygens spin axis away from the sun
;   orthogonal_tip = the component of the tip of the Huygens spin axis toward 'SW'
; Outputs:
;   intensity(6,50,nwavls,2) where
;     6 is the the column number
;     50 is the row number
;     nwavls is the wavelength of all the intensities
;     0 (Vertical) or 1 (Horizontal) channel

common saved,model_name_old,alt_old,tables_read,wavl,solar_zen_angle, $
  theta,phi,idnc,zeniths_blue_vertical,azimuths_blue_vertical, $
  zeniths_blue_horizontal,azimuths_blue_horizontal

if tables_read eq 0 then begin
  zeniths_blue_vertical=fltarr(6,50)
  azimuths_blue_vertical=fltarr(6,50)
  zeniths_blue_horizontal=fltarr(6,50)
  azimuths_blue_horizontal=fltarr(6,50)
  for c=0,1 do begin
    if c eq 0 then begin
      openr,lun,'C:\Documents and Settings\Lyn Doose\My Documents\TABLE_8-2 Blue Vertical.TBL', $
        /get_lun
    endif
    if c eq 1 then begin
      openr,lun,'C:\Documents and Settings\Lyn Doose\My Documents\TABLE_8-1 Blue Horizontal.TBL', $
        /get_lun
    endif
    zeniths=fltarr(6,50)
    azimuths=fltarr(6,50)
    values=fltarr(12)
    str=''
    readf,lun,str
    readf,lun,str
    for i=0,49 do begin
      readf,lun,values
      zeniths[*,i]=[values[1],values[3],values[5],values[7],values[9],values[11]]
      azimuths[*,i]=[values[0],values[2],values[4],values[6],values[8],values[10]]
    endfor
    free_lun,lun
    if c eq 0 then begin
      zeniths_blue_vertical=zeniths
      azimuths_blue_vertical=azimuths
    endif
    if c eq 1 then begin
      zeniths_blue_horizontal=zeniths
      azimuths_blue_horizontal=azimuths
    endif
  endfor
  tables_read=1
endif

azimuths_blue_vertical=azimuths_blue_vertical+az
azimuths_blue_horizontal=azimuths_blue_horizontal+az
index=where(azimuths_blue_vertical gt 180.0)
if index[0] ne -1 then azimuths_blue_vertical[index]= $
  360.0-azimuths_blue_vertical[index]
index=where(azimuths_blue_horizontal gt 180.0)
if index[0] ne -1 then azimuths_blue_horizontal[index]= $
  360.0-azimuths_blue_horizontal[index]

disr_2_titan_coords,azimuths_blue_vertical,zeniths_blue_vertical,az, $
  solar_zen_angle,tip_away_from_sun,orthogonal_tip,az_blue_vertical, $
  zen_blue_vertical

disr_2_titan_coords,azimuths_blue_horizontal,zeniths_blue_horizontal,az, $
  solar_zen_angle,tip_away_from_sun,orthogonal_tip,az_blue_horizontal, $
  zen_blue_horizontal

if model_name ne model_name_old then begin
  read_intensi_ir29_fn,model_name,namlist,numg,wavl,f0,fdd,fd,fup,iup,idn,alts, $
    solar_zenith_angle,theta,phi
  model_name_old=model_name
endif

if alt_old ne alt then begin
  interp_intensi_vis,alt,fdd,fd,fup,idn,fddc,fdc,fuc,idnc
  alt_old=alt
endif

; Interpolate in idnc for the I vs. azimuth at each row's
; zenith angle
ivsaz_blue_vertical=fltarr(6,29)
ivsaz_blue_horizontal=fltarr(6,29)
intens=fltarr(6,50,n_elements(wavl),2)

for w=0,n_elements(wavl)-1 do begin
  for i=0,n_elements(theta)-1 do begin
    ivsaz_blue_vertical[*,i]=interpol(idnc[*,i,w],phi,az_blue_vertical[*,i])
    ivsaz_blue_horizontal[*,i]=interpol(idnc[*,i,w],phi,az_blue_horizontal[*,i])
    stupid=1
  endfor
  for col=0,5 do begin
    intens[col,*,w,0]=interpol(ivsaz_blue_vertical[col,*],theta,zen_blue_vertical[col,*])
    intens[col,*,w,1]=interpol(ivsaz_blue_horizontal[col,*],theta,zen_blue_horizontal[col,*])
    stupid=1
  endfor
endfor

intens=intens/9.052506^2

end